import React from 'react';
import r3 from '../../../src'

const BarChart = r3.BarChart;
const ScatterPlot = r3.ScatterPlot;
const LineChart = r3.LineChart;
const HeatMap = r3.HeatMap;
const Preloader = r3.Preloader;

import css from './index.styl'

function randomInteger(min, max) {
  var rand = min - 0.5 + Math.random() * (max - min + 1);
  rand = Math.round(rand);
  return rand;
}

function randomArray(length, min=0, max=0) {
  let res = [];
  for(let i = 0; i < length; i++) {
    res.push(randomInteger(min, max))
  }
  return res;
}

class Demo extends React.Component {
  static defaultProps =  {
    width: 400,
    height: 300
  };

  componentDidMount() {
    setTimeout(()=>{
      fetch('json/heatmap.json').then((res) => {
        return res.json()
      }).then((json) =>{
        this.setState({
          heatMapData: json
        })
      })
    }, 1800)
  }

  componentWillMount() {
    this.randomScatter();
    this.randomLineChart();
  }

  state = {
    barChartData: [ { name: 'jan', value: -6.5 }, { name: 'feb', value: -6.7 }, { name: 'mar', value: -1 }, { name: 'apr', value: 6.7 }, { name: 'may', value: 13.2 }, { name: 'jun', value: 17.0 }, { name: 'jul', value: 19.2 }, { name: 'aug', value: 17.0 }, { name: 'sep', value: 11.3 }, { name: 'oct', value: 5.6 }, { name: 'nov', value: -1.2 }, { name: 'dec', value: -5.2 } ],
    colorScale: [ { color:'#0000FF', value: -30 }, { color:'#135BA9', value: -20 }, { color:'#98cced', value: 0 }, { color:'#eba39f', value: 0.0001 }, { color:'#e74040', value: 17 }, { color:'#E50C0C', value: 22 }, { color:'#E50C0C', value: 27 } ],
    heatMapData: []
  };

  randomScatter(e) {
    if (e) e.preventDefault();
    this.setState({
      scatterData: randomArray(randomInteger(10, 50)).map(()=> {
        return {
          x: randomInteger(-20, 20),
          y: randomInteger(-20, 20),
          z: randomInteger(-20, 20)
        }
      })
    })
  }
  randomLineChart(e) {
    if (e) e.preventDefault();
    this.setState({
      lineChartData: randomArray(randomInteger(8, 20)).map(()=> {
        return {
          x: randomInteger(-20, 20),
          y: randomInteger(-20, 20)
        }
      }).sort((a, b)=> a.x - b.x)
    })
  }

  randomHeatmap(e) {
    e.preventDefault();
    this.setState({
      heatMapData: this.state.heatMapData.map((item) =>{
        return {
          name: item.name,
          x: item.x,
          z: ((()=>{
            if (~(['jan', 'feb', 'mar', 'oct', 'nov', 'dec'].indexOf(item.name))) {
              return randomInteger(-15, 1)
            } else {
              return randomInteger(0, 15)
            }
          })())
        }
      })
    })
  }

  randomBarChart(e) {
    e.preventDefault();
    this.setState({
      barChartData: this.state.barChartData.map((v)=> {
        return {
          name: v.name,
          value: randomInteger(-20, 20)
        }
      })
    })
  }

  render() {
    return (
      <div className={css.wrap}>
        <div className={css.diagramWrap}>
          <h1>BarChart</h1>
          <p><a href="#" onClick={this.randomBarChart.bind(this)}>Rerender</a></p>
          <BarChart data={this.state.barChartData}
                    color={this.state.colorScale}>
          </BarChart>
        </div>
        <div className={css.diagramWrap}>
          <h1>ScatterPlot</h1>
          <p><a href="#" onClick={this.randomScatter.bind(this)}>Rerender</a></p>
          <ScatterPlot data={this.state.scatterData}/>
        </div>
        <div className={css.diagramWrap}>
          <h1>LineChart</h1>
          <p><a href="#" onClick={this.randomLineChart.bind(this)}>Rerender</a></p>
          <LineChart data={this.state.lineChartData}/>
        </div>
        <div className={css.diagramWrap}>
          <h1>HeatMap</h1>
          <p><a href="#" onClick={this.randomHeatmap.bind(this)}>Rerender</a></p>
          <div className={css.heatmapChartWrap}>
            <Preloader show={!this.state.heatMapData.length}/>
            <HeatMap data={this.state.heatMapData}
                     color={this.state.colorScale}/>
          </div>
        </div>
      </div>
    );
  }
}

export default Demo
