'use strict';

const path = require("path");
const NODE_ENV = process.env.NODE_ENV;
const webpack = require('webpack');
const HtmlWebpackPlugin = require('html-webpack-plugin');
const ExtractTextPlugin = require("extract-text-webpack-plugin");

let BUILD = NODE_ENV === 'production';

let config = {
  entry: {
    app: ["./index.js"]
  },
  output: {
    path: path.resolve(__dirname, "build"),
    filename: BUILD ? '[name].[hash].js' : '[name].bundle.js',
    chunkFilename: BUILD ? '[name].[hash].js' : '[name].bundle.js'
  },
  externals: {
    "react": 'React',
    'react-dom': 'ReactDOM'
  },
  watch: !BUILD,
  devtool: !BUILD ? 'eval' : null,
  plugins: [
    new webpack.NoErrorsPlugin(),
    new ExtractTextPlugin('[name].[hash].css', {disable: !BUILD}),
    new webpack.ProvidePlugin({
      'Promise': 'es6-promise',
      'fetch': 'imports?this=>global!exports?global.fetch!whatwg-fetch'
    })
  ],
  module: {
    preLoaders:[],
    loaders: [
      {
        test: /\.jsx?$/,
        loader: 'babel',
        query: {
          presets: [
            'react',   // react
            'es2015',  // ES6
            'stage-0', // ES7 double colon
            "stage-1", // ES7 decorator
            'stage-2'  // ES7 spread operator
          ],
          plugins: [
            'transform-runtime',          // support babel functions in a separate module
            "transform-decorators-legacy" // ES7 decorator
          ]
        },
        exclude: /\/node_modules\//

      },
      {
        test: /\.styl$/,
        loader: ExtractTextPlugin.extract(
          'style',
          'css-loader!stylus-loader?resolve url'
        )
      },
      {
        test: /\.css$/,
        loader: ExtractTextPlugin.extract(
          'style',
          'css-loader'
        )
      },
      {
        test: /\.(jpe?g|png|gif|svg|woff|woff2|eot|ttf)(\?v=[0-9].[0-9].[0-9])?$/,
        loader: 'file?name=[sha512:hash:base64:7].[ext]'
      }
    ]
  },
  devServer: {
    host: 'localhost',
    port: 1111,
    contentBase: path.resolve(__dirname, "build"),
    hot: true
  }
};

config.plugins.push(
  new HtmlWebpackPlugin({
    template: './index.html',
    inject: 'body'
  })
);

if (BUILD) {
  config.plugins.push(
    new webpack.optimize.UglifyJsPlugin({
      compress: {
        warnings: false,
        drop_console: true,
        unsafe: true
      }
    }),
    new webpack.optimize.DedupePlugin()
  );
}

module.exports = config;

