import React from 'react';
import BarChart from './index.js';
import TestUtils from 'react/lib/ReactTestUtils';

describe('Компонент BarChart', function () {

  beforeEach(function() {

    this.data = [
      {
        name: 'янв',
        value: -6.5
      },
      {
        name: 'июнь',
        value: 20
      }
    ];

    this.TestUtils = TestUtils;
    this.shallowRenderer = TestUtils.createRenderer();
    this.shallowRenderer.render(<BarChart data={this.data}/>);
  });
  
  it('тип svg', function () {
    let instance = this.shallowRenderer.getRenderOutput();
    expect(instance.type).toBe('svg')
  });

  it('корректный className', function () {
    let instance = this.shallowRenderer.getRenderOutput();
    expect(instance.props.className).toBe('r3-barchart')
  });

  it('показывается ось x и y по умолчанию', function () {
    var renderedComponent = TestUtils.renderIntoDocument(<BarChart data={this.data}/>);
    let x = TestUtils.scryRenderedDOMComponentsWithClass(renderedComponent, 'r3-barchart-yaxis');
    let y = TestUtils.scryRenderedDOMComponentsWithClass(renderedComponent, 'r3-barchart-xaxis');
    expect(x.length).toBe(1);
    expect(y.length).toBe(1);
  });

  it('скрываются ось x и y при ключе disable в true', function () {
    var renderedComponent = TestUtils.renderIntoDocument(<BarChart data={this.data} xAxis={{disable: true}} yAxis={{disable: true}}/>);
    let x = TestUtils.scryRenderedDOMComponentsWithClass(renderedComponent, 'r3-barchart-yaxis');
    let y = TestUtils.scryRenderedDOMComponentsWithClass(renderedComponent, 'r3-barchart-xaxis');
    expect(x.length).toBe(0);
    expect(y.length).toBe(0);
  });
});