import React, {PropTypes, Component} from 'react';
const ease = require('d3-ease');

class Box extends Component {

  state = {
    active: false
  };

  onMouseEnterHandler() {
    this.setState({active: true});
  }

  onMouseLeaveHandler() {
    this.setState({active: false});
  }

  getStyle() {
    return {
      transition: 'fill 1s ease-in-out, stroke-width .3s linear'
    }
  }


  /**
   * Рендрим подсказку
   * @param active если active === true то показываем подсказку, иначе скрываем
   * @return {XML}
   */
  renderText(active) {
    const { value, x, y, height} = this.props;
    if(active) {
      if (value.z || value.z === 0) {
        return <text x={x} y={'-1em'} dx="-.2em" dy="0em">{`${value.x.toFixed(0)}, ${value.name}, ${value.z.toFixed(1)}`}</text>
      } else {
        return null
      }
    } else {
      return null
    }
  }

  render() {
    const { fill,
            height,
            width,
            x,
            y } = this.props;

    const { active } = this.state;

    return (
      <g onMouseEnter={this.onMouseEnterHandler.bind(this)}
         onMouseLeave={this.onMouseLeaveHandler.bind(this)}>
        <rect fill={fill}
              height={height}
              strokeWidth={ !active ? 0 : 1}
              stroke={'#FFEA00'}
              style={this.getStyle()}
              width={width}
              x={x}
              y={y}/>
        {this.renderText(active)}
      </g>
    );
  }
}

export default Box;
