import React, {Component, PropTypes} from 'react'
const ease = require('d3-ease');

class Point extends Component {

  static propTypes = {
    path: PropTypes.string.isRequired,
    value: PropTypes.array.isRequired,
    x: PropTypes.number.isRequired,
    xCenter: PropTypes.number.isRequired,
    y: PropTypes.number.isRequired,
    yCenter: PropTypes.number.isRequired,
    z: PropTypes.number.isRequired
  };

  static defaultProps = {
    x: 0,
    y: 0,
    z: 0
  };

  state = {
    active: false,
    milliseconds: 0,
    x: this.props.xCenter,
    y: this.props.yCenter,
    z: 0
  };

  shouldComponentUpdate(nextProps, nextState) {
    return this.props.z !== this.state.z ||
      this.props.x !== this.state.x ||
      this.props.y !== this.state.y ||
      this.state.active !== nextState.active
  }

  componentDidMount() {
    this.interval = requestAnimationFrame(this.tick.bind(this));
  }

  componentWillUnmount() {
    cancelAnimationFrame(this.interval);
  }

  componentWillReceiveProps() {
    this.setState({
      milliseconds: 0,
      z: this.props.z
    });
  }

  tick() {
    this.setState({
      milliseconds: this.state.milliseconds + 1000 / 60
    });
    requestAnimationFrame(this.tick.bind(this))
  }

  onMouseEnterHandler() {
    this.setState({active: true});
  }

  onMouseLeaveHandler() {
    this.setState({active: false});
  }

  /**
   * Рендрим подсказку
   * @param active если active === true то показываем подсказку, иначе скрываем
   * @return {JSX}
   */
  renderText(active) {
    const { value, x, y } = this.props;
    if (active) {
      return (
        <g>
          <text x={x} y={y} dx=".8em" dy="0em">{`x: ${value[0].toFixed(1)}`}</text>
          <text x={x} y={y} dx=".8em" dy="1em">{`y: ${value[1].toFixed(1)}`}</text>
        </g>
      )
    } else {
      return null
    }
  }

  render() {

    const { path, fill, x, y, z } = this.props;

    this.state.x = this.state.x + (x - this.state.x) * ease.easePolyOut(Math.min(1, this.state.milliseconds / 1000), 2);
    this.state.y = this.state.y + (y - this.state.y) * ease.easePolyOut(Math.min(1, this.state.milliseconds / 1000), 2);
    this.state.z = this.state.z + (z - this.state.z) * ease.easePolyOut(Math.min(1, this.state.milliseconds / 1000), 2);

    return (
      <g onMouseEnter={this.onMouseEnterHandler.bind(this)}
         onMouseLeave={this.onMouseLeaveHandler.bind(this)}>
        <path d={path}
              fill="transparent"/>
        <circle cx={this.state.x}
                cy={this.state.y}
                fill={fill}
                r={this.state.active ? this.state.z+1 : this.state.z}/>
        {this.renderText(this.state.active)}
      </g>
    );
  }

}

export default Point;

