import React, {Component, PropTypes} from 'react'
import Point from './point'

const shape = require('d3-shape');

class Points extends Component {

  static propTypes = {
    fill: PropTypes.string.isRequired,
    voronoi: PropTypes.array.isRequired,
    xScale: PropTypes.func.isRequired,
    yScale: PropTypes.func.isRequired,
    zScale: PropTypes.func.isRequired
  } ;

  /**
   * Возвращает объект для атрибута style, для обертки над точками
   * @returns {{transform: *}}
   */
  getStyle() {
    const { dx } = this.props;
    return {transform: `translate(${dx}px,0px)`}
  }

  /**
   * Строем svg path, который является полигоном диаграммы Вороного.
   * + замыкаем его (Параметр Z в path)
   * @param data массив точек, каждая из которых является вершиной многоугольника
   * @return {string} многоугольник в виде приемлемом для svg path
   */
  getPath(data) {
    const res = data.map((item)=>{
      return [
        this.props.xScale(item[0]),
        this.props.height - this.props.yScale(item[1])
      ]
    });
    return shape.line()(res) + 'Z'
  }

  render() {
    const { fill,
            height,
            voronoi,
            xScale,
            yScale,
            zScale} = this.props;

    // находим центр диаграммы, чтобы новые точки появлялись из нее
    // далее передаем это в компонент Point
    const xCenter = xScale.range()[1]/2;
    const yCenter = yScale.range()[1]/2;

    const points = voronoi.map((val, i) => {
      const _height = yScale(val.data[1]),
            path = this.getPath(val),
            x = xScale(val.data[0]),
            y = height - _height,
            z = zScale(val.data[2]);

      return (
        <Point fill={fill}
               key={i}
               path={path}
               value={val.data}
               x={x}
               xCenter={xCenter}
               yCenter={yCenter}
               y={y}
               z={z}/>
      )
    });

    return (
      <g style={this.getStyle()}>{points}</g>
    );
  }

}

export default Points;
