import React from 'react';
import ScatterPlot from './index.js';
import TestUtils from 'react/lib/ReactTestUtils';

describe('Компонент ScatterPlot', function () {

  beforeEach(function() {

    this.data = [
      {
        x:1,
        y:2,
        z:1
      },
      {
        x:6,
        y:3,
        z:2
      },
      {
        x:3,
        y:8,
        z:4
      }
    ];

    this.TestUtils = TestUtils;
    this.shallowRenderer = TestUtils.createRenderer();
    this.shallowRenderer.render(<ScatterPlot data={this.data}/>);
  });
  
  it('тип svg', function () {
    let instance = this.shallowRenderer.getRenderOutput();
    expect(instance.type).toBe('svg')
  });

  it('корректный className', function () {
    let instance = this.shallowRenderer.getRenderOutput();
    expect(instance.props.className).toBe('r3-scatter-plot')
  });

  it('показывается ось x и y по умолчанию', function () {
    var renderedComponent = TestUtils.renderIntoDocument(<ScatterPlot data={this.data}/>);
    let x = TestUtils.scryRenderedDOMComponentsWithClass(renderedComponent, 'r3-scatter-plot-yaxis');
    let y = TestUtils.scryRenderedDOMComponentsWithClass(renderedComponent, 'r3-scatter-plot-xaxis');
    expect(x.length).toBe(1);
    expect(y.length).toBe(1);
  });

  it('скрываются ось x и y при ключе disable в true', function () {
    var renderedComponent = TestUtils.renderIntoDocument(<ScatterPlot data={this.data} xAxis={{disable: true}} yAxis={{disable: true}}/>);
    let x = TestUtils.scryRenderedDOMComponentsWithClass(renderedComponent, 'r3-scatter-plot-yaxis');
    let y = TestUtils.scryRenderedDOMComponentsWithClass(renderedComponent, 'r3-scatter-plot-xaxis');
    expect(x.length).toBe(0);
    expect(y.length).toBe(0);
  });

  it('корректная работа метода getDomain', function () {
    const xDomain = this.shallowRenderer.getMountedInstance().getDomain('x', this.data);
    const yDomain = this.shallowRenderer.getMountedInstance().getDomain('y', this.data);
    const zDomain = this.shallowRenderer.getMountedInstance().getDomain('z', this.data);
    const domainWithDelta = this.shallowRenderer.getMountedInstance().getDomain('x', this.data, .5);
    const domainWithMinMax = this.shallowRenderer.getMountedInstance().getDomain('x', this.data, .1, 1, 10);

    expect(xDomain).toEqual([.9, 6.6]);
    expect(yDomain).toEqual([1.8, 8.8]);
    expect(zDomain).toEqual([.9, 4.4]);
    expect(domainWithDelta).toEqual([.5, 9]);
    expect(domainWithMinMax).toEqual([.9, 11]);
  });

});