/**
 * Анимируем элемент path svg
 * Линия от нулевой длинны превращается в исходную. Эффект достигается благодаря тому, что сначала
 * этой линии задается пунктирный тип вида '- - - - - ',
 * где расстояние между пунктирами (' ') равно длине линиии, как и пунктирная часть ('-').
 * Также происходит сдвиг начала линии на расстояние длины линии,
 * так что сначала идет пробельная часть (' ') и линии невидно вовсе.
 * Далее изменяется этот отступ (stroke-dashoffset) до 0 и кажется что линия
 * постепенно увеличивается до усходной
 * @param {DOM} path дом элемент, который будет анимироваться
 * @param {string} time время анимации
 * @param {string} animate тип анимации
 */
export function animatePath(path, time = '1s', animate = 'linear') {
  var length = path.getTotalLength();
  path.style.transition = path.style.transition = 'none';
  path.style.strokeDasharray = length + ' ' + length;
  path.style.strokeDashoffset = length;
  path.getBoundingClientRect(); // хак
  path.style.transition = path.style.transition = `stroke-dashoffset ${time} ${animate}`;
  path.style.strokeDashoffset = '0';
}

/**
 * Скрываем элемент path
 * Обычно применяется с animatePath. Lействует аналогично animatePath, однако после
 * "квазискрытия" не происходит показ линии
 * @param {DOM} path
 */
export function hidePath(path) {
  const delta = 9999; // cкрываем наверняка
  const length = delta * path.getTotalLength();
  path.style.transition = path.style.transition = 'none';
  path.style.strokeDasharray = length + ' ' + length;
  path.style.strokeDashoffset = length;
}
