'use strict';

const path = require("path");
const NODE_ENV = process.env.NODE_ENV;
const webpack = require('webpack');

let BUILD = NODE_ENV === 'production';

let config = {
  entry: {
    app: ["./src/index.js"]
  },
  output: {
    path: path.resolve(__dirname, "dist"),
    filename: BUILD ? 'r3.js' : '[name].bundle.js',
    libraryTarget: "umd",
    library: "Foo"
  },
  externals: {
    "react": {
      root: 'React',
      commonjs2: 'react',
      commonjs: 'react',
      amd: 'react'
    },
    'react-dom': 'ReactDOM'
  },
  watch: !BUILD,
  devtool: !BUILD ? 'eval' : 'source-map',
  plugins: [
    new webpack.NoErrorsPlugin()
  ],
  module: {
    preLoaders:[],
    loaders: [
      {
        test: /\.jsx?$/,
        loader: 'babel',
        query: {
          presets: [
            'react',   // react
            'es2015',  // ES6
            'stage-0', // ES7 double colon
            "stage-1", // ES7 decorator
            'stage-2'  // ES7 spread operator
          ],
          plugins: [
            'transform-runtime',          // support babel functions in a separate module
            "transform-decorators-legacy" // ES7 decorator
          ]
        },
        exclude: /\/node_modules\//
      }
    ]
  }
};

if (BUILD) {
  config.plugins.push(
    new webpack.optimize.UglifyJsPlugin({
      compress: {
        warnings: false,
        drop_console: true,
        unsafe: true
      }
    }),
    new webpack.optimize.DedupePlugin()
  );
}

module.exports = config;

